@@ -53,7 +53,6 @@ from __future__ import annotations
 
 import shutil
 import textwrap
-import warnings
 from abc import ABC, abstractmethod
 from dataclasses import dataclass
 from typing import (
@@ -319,12 +318,12 @@ class _GroupedErrors:
             if len(v) == 1:
                 ungrouped_pairs.append((v[0]))
             else:
-                groups[k] = _GroupedErrors.make([e for i, e in v], index + 1)
+                groups[k] = _GroupedErrors.make([e for _, e in v], index + 1)
 
         def get_index(pair: Tuple[int, Err1]) -> int:
             return pair[0]
 
-        ungrouped: List[Err1] = [e for i, e in sorted(ungrouped_pairs, key=get_index)]
+        ungrouped: List[Err1] = [e for _, e in sorted(ungrouped_pairs, key=get_index)]
 
         return _GroupedErrors(groups, ungrouped)
 
@@ -397,7 +396,7 @@ def wrap(
     ) -> Callable[_Parameters, Res[_ReturnType]]:
         def wrapper(*args, **kwargs) -> Res[_ReturnType]:  # type: ignore
             try:
-                res: Res[_ReturnType] = func(*args, **kwargs)
+                res: Res[_ReturnType] = func(*args, **kwargs)  # type: ignore
             except Exception as e:  # pylint: disable=broad-except
                 if (not keep) or any([isinstance(e, t) for t in keep]):
                     res = Err.make(f"{type(e).__name__} thrown: {e}")
@@ -405,7 +404,7 @@ def wrap(
                     raise
             return res
 
-        return wrapper
+        return wrapper  # type: ignore
 
     return decorator
 
@@ -561,18 +560,6 @@ def flat_map(f: Callable[[_Value_co], Res[_ReturnType]], r: Res[_Value_co]) -> R
         return f(r)
 
 
-def flatMap(f: Callable[[_Value_co], Res[_ReturnType]], r: Res[_Value_co]) -> Res[_ReturnType]:
-    """
-    Enables the chaining computations that can error (deprecated)
-
-    See also: :func:`.flat_map`
-    """
-    warnings.warn(
-        "flatMap has been deprecated, use flat_map instead", DeprecationWarning, stacklevel=2
-    )
-    return flat_map(f, r)
-
-
 def collect_seq(seq: Sequence[Res[_Value_co]]) -> Res[Sequence[_Value_co]]:
     """
     Collects a sequence of results
